# Notice: this package does not currently support discord.py 2.0.0

This project has been on pause since the 2.0.0 rewrites.

---

# dpytest

[![Build Status](https://travis-ci.com/CraftSpider/dpytest.svg?branch=master)](https://travis-ci.com/CraftSpider/dpytest)
[![Documentation Status](https://readthedocs.org/projects/dpytest/badge/?version=latest)](https://dpytest.readthedocs.io/en/latest/?badge=latest)
[![Discord Server](https://img.shields.io/discord/523301176309972993.svg?label=Support%20Discord)](https://discord.gg/aNe8DqAuxd)


This is a package to allow testing of discord.py.
It is only compatible with the rewrite version, and is still in alpha.
If using pytest, it is suggested to use pytest-asyncio for test running, otherwise the user will need
to provide their own async test runner.

# Notice

For discord.py 1.7.X, use `dpytest 0.5.3`

For discord.py 2.X.X, use `dpytest>=0.6`

# Documentation

Documentation can be found at [dpytest.readthedocs.io](https://dpytest.readthedocs.io/en/latest/), including examples and tutorials
